@@ -352,7 +352,7 @@ DicomFile::ReadCSAHeader(const string& header, const string& search, string& val
 		pos = header.find(search, pos);
 		if (pos == string::npos) return 0; // search string not found
 
-		if (search.compare(header.substr(pos, 64).c_str())) {
+		if (search.compare(header.substr(pos, 64).c_str())) { // wrong hit
 			pos += 1;
 			continue;
 		}
@@ -362,6 +362,11 @@ DicomFile::ReadCSAHeader(const string& header, const string& search, string& val
 		wxInt32 n_values;
 		n_values = *reinterpret_cast<wxInt32*> (&header.substr(pos)[0]);
 
+		if (n_values > 10000) { // crude way to look for another wrong hit
+			pos -= 63;
+			continue;
+		}
+
 		pos += 3*4;
 		intval2 = *reinterpret_cast<wxUint32*>(&header.substr(pos)[0]);
 
@@ -409,6 +414,11 @@ DicomFile::ReadCSAHeader(const string& header, const string& search, vector<stri
 
 		n_values = *reinterpret_cast<wxInt32*> (&header.substr(pos)[0]);
 
+		if (n_values > 10000) { // crude way to look for another wrong hit
+			pos -= 63;
+			continue;
+		}
+
 		pos += 3*4;
 		intval2 = *reinterpret_cast<wxUint32*>(&header.substr(pos)[0]);
 
