@@ -369,6 +369,9 @@ SeriesHandler::ReadVolIds(DicomFile& file)
 	else info.ids.push_back("");
 	if (ImageType.find("T2 MAP") != std::string::npos) info.ids.push_back("T2MAP");
 	else info.ids.push_back("");
+	if (ImageType.find("\\M\\") != std::string::npos) info.ids.push_back("M");
+	else if (ImageType.find("\\P\\") != std::string::npos) info.ids.push_back("P");
+	else info.ids.push_back("");
 
 	vector<double> rotation;
 	rotation.resize(9, 0);
